import { TableFilter } from "./filter";
export declare enum DetailLevel {
    DEBUG = 0,
    INFO = 1,
    WARN = 2,
    ERROR = 3,
    FATAL = 30,
    MAX = 9999
}
export declare enum ResultCode {
    OK = "OK",
    IO = "IO",
    VALID = "VALID",
    INVALID = "INVALID",
    DUPLICATE = "DUPLICATE",
    DATA_ACCESS = "DATA_ACCESS",
    NOT_FOUND = "NOT_FOUND",
    UNKNOWN = "UNKNOWN",
    DELETE = "DELETE"
}
export interface ResultDetail {
    text: string;
    code: string;
    type: string;
    level: number;
}
export declare abstract class AbstractResult {
    operation: string;
    fqn: string;
    messages: ResultDetail[];
    stamp: Date;
    protected constructor(data?: any);
    hasError(): ResultDetail;
    hasWarn(): ResultDetail;
    findDetail(minLevel?: number, maxLevel?: number): ResultDetail;
    findMaxDetail(): ResultDetail;
    error(text: string, code?: string, type?: string): ResultDetail;
    warn(text: string, code?: string, type?: string): ResultDetail;
    info(text: string, code?: string, type?: string): ResultDetail;
    ok(text: string, type?: string): ResultDetail;
    static fromData(data: any): AbstractResult;
}
export declare class EditResult extends AbstractResult {
    key: string;
    constructor(data?: any);
    static fromData(data: any): EditResult;
}
export declare class QueryResult<E> extends AbstractResult {
    items: E[];
    rows: number;
    hasMore: boolean;
    constructor(data?: any);
    static fromData<E>(data: any): QueryResult<E>;
}
export declare class ErrorResult extends AbstractResult {
    exception: Error;
    constructor(data?: any);
    static fromData(data: any): ErrorResult;
}
/**
 * elastic search result
 */
export interface SearchResult<E> {
    total?: number;
    took?: number;
    timedOut?: boolean;
    rows: E[];
}
export interface ResultFilter extends TableFilter {
    operation?: string;
    status?: string;
    userId?: string;
}
